package tech.nevets.admininv;

import org.bukkit.Bukkit;
import org.bukkit.Location;
import org.bukkit.World;
import org.bukkit.configuration.file.FileConfiguration;
import org.bukkit.configuration.file.YamlConfiguration;
import org.bukkit.entity.Player;
import org.bukkit.inventory.ItemStack;
import org.bukkit.inventory.PlayerInventory;
import org.bukkit.plugin.java.JavaPlugin;

import java.io.File;
import java.io.IOException;
import java.util.List;
import java.util.UUID;
import java.util.logging.Level;

public class SerializablePlayerInventory {
    private ItemStack[] normalItems;
    private ItemStack[] normalArmor;
    private ItemStack[] adminItems;
    private ItemStack[] adminArmor;
    private UUID playerUUID;
    private boolean inAdminMode;
    private YamlConfiguration inventoryConfig;
    private File inventoryConfigFile;
    private JavaPlugin plugin;
    private Location adminLoc;
    private Location normalLoc;

    public SerializablePlayerInventory(UUID playerUUID, JavaPlugin parentPlugin) {
        this.playerUUID = playerUUID;
        this.plugin = parentPlugin;
        File[] arr$ = parentPlugin.getDataFolder().listFiles();
        int len$ = arr$.length;

        for(int i$ = 0; i$ < len$; ++i$) {
            File f = arr$[i$];
            YamlConfiguration config;
            List nitems;
            List narmor;
            List aitems;
            List aarmor;
            if (f.getName().equals(playerUUID.toString() + ".v1.0")) {
                try {
                    this.plugin.getLogger().info("Reading from file.");
                    config = YamlConfiguration.loadConfiguration(f);
                    this.inAdminMode = config.getBoolean("misc.inAdminMode");
                    nitems = (List)config.get("normal.items");
                    this.normalItems = (ItemStack[])nitems.toArray(new ItemStack[0]);
                    narmor = (List)config.get("normal.armor");
                    this.normalArmor = (ItemStack[])narmor.toArray(new ItemStack[0]);
                    aitems = (List)config.get("admin.items");
                    this.adminItems = (ItemStack[])aitems.toArray(new ItemStack[0]);
                    aarmor = (List)config.get("admin.armor");
                    this.adminArmor = (ItemStack[])aarmor.toArray(new ItemStack[0]);
                    int x = config.getInt("normal.location.x");
                    int y = config.getInt("normal.location.y");
                    int z = config.getInt("normal.location.z");
                    String worldName = config.getString("normal.location.world");
                    World world = Bukkit.getWorld(worldName);
                    this.normalLoc = new Location(world, x, y, z);
                    x = config.getInt("admin.location.x");
                    y = config.getInt("admin.location.y");
                    z = config.getInt("admin.location.z");
                    worldName = config.getString("admin.location.world");
                    world = Bukkit.getWorld(worldName);
                    this.adminLoc = new Location(world, x, y, z);
                    this.inventoryConfig = config;
                    this.inventoryConfigFile = f;
                    return;
                } catch (ClassCastException var17) {
                    this.plugin.getLogger().log(Level.SEVERE, "Invalid cast", var17);
                }
            }
        }

        Player player = Bukkit.getPlayer(playerUUID);
        this.plugin.getLogger().log(Level.INFO, "No file for player: {0}. Creating new instance.", player.getName());
        PlayerInventory inventory = player.getInventory();
        this.normalItems = inventory.getContents().clone();
        this.normalArmor = inventory.getArmorContents().clone();
        this.adminItems = new ItemStack[36];
        this.adminArmor = new ItemStack[4];
        this.inAdminMode = false;
        this.normalLoc = Bukkit.getPlayer(playerUUID).getLocation();
        this.adminLoc = Bukkit.getPlayer(playerUUID).getLocation();
        this.inventoryConfigFile = new File(this.plugin.getDataFolder() + File.separator + playerUUID.toString() + ".v1.0");
        this.inventoryConfig = new YamlConfiguration();
    }

    public SerializablePlayerInventory(Player p, JavaPlugin parentPlugin) {
        this(p.getUniqueId(), parentPlugin);
    }

    public synchronized void toggleAdminInventory() {
        Player player = Bukkit.getPlayer(this.playerUUID);
        PlayerInventory inventory = player.getInventory();
        if (this.inAdminMode) {
            this.adminItems = inventory.getContents().clone();
            this.adminArmor = inventory.getArmorContents().clone();
            inventory.setContents(this.normalItems);
            inventory.setArmorContents(this.normalArmor);
        } else {
            this.normalItems = inventory.getContents().clone();
            this.normalArmor = inventory.getArmorContents().clone();
            inventory.setContents(this.adminItems);
            inventory.setArmorContents(this.adminArmor);
        }

        FileConfiguration config = this.plugin.getConfig();
        if (config.contains("teleportOnSwitch")) {
            boolean teleport = config.getBoolean("teleportOnSwitch");
            if (teleport) {
                if (this.inAdminMode) {
                    this.adminLoc = player.getLocation();
                    if (this.normalLoc != null) {
                        player.teleport(this.normalLoc);
                    }
                } else {
                    this.normalLoc = player.getLocation();
                    if (this.adminLoc != null) {
                        player.teleport(this.adminLoc);
                    }
                }
            }
        }
        this.inAdminMode = !this.inAdminMode;
    }

    public synchronized void save() {
        this.inventoryConfig.set("normal.items", this.normalItems);
        this.inventoryConfig.set("normal.armor", this.normalArmor);
        this.inventoryConfig.set("admin.items", this.adminItems);
        this.inventoryConfig.set("admin.armor", this.adminArmor);
        this.inventoryConfig.set("misc.inAdminMode", this.inAdminMode);
        this.inventoryConfig.set("normal.location.x", this.normalLoc.getX());
        this.inventoryConfig.set("normal.location.y", this.normalLoc.getY());
        this.inventoryConfig.set("normal.location.z", this.normalLoc.getZ());
        this.inventoryConfig.set("normal.location.world", this.normalLoc.getWorld().getName());
        this.inventoryConfig.set("admin.location.x", this.adminLoc.getX());
        this.inventoryConfig.set("admin.location.y", this.adminLoc.getY());
        this.inventoryConfig.set("admin.location.z", this.adminLoc.getZ());
        this.inventoryConfig.set("admin.location.world", this.adminLoc.getWorld().getName());

        try {
            this.inventoryConfig.save(this.inventoryConfigFile);
        } catch (IOException var2) {
            this.plugin.getLogger().log(Level.SEVERE, "Error saving config file for player: " + Bukkit.getPlayer(this.playerUUID).getName(), var2);
        }
    }

    public boolean getInAdminMode() {
        return this.inAdminMode;
    }
}